AudioMetadata class

Constructors

AudioMetadata({required String title, required String audioUrl, required AudioType type})

Properties

audioUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
type → AudioType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseAudioMetadata(String? jsonString) → List<AudioMetadata>