FeaturesConfigBuilder class

Constructors

FeaturesConfigBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() → FeaturesConfig
enableEditorV2(dynamic enableEditorV2) → FeaturesConfigBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAiClipping(dynamic aiClipping) → FeaturesConfigBuilder
setAudioBrowser(dynamic audioBrowser) → FeaturesConfigBuilder
setCameraConfig(dynamic cameraConfig) → FeaturesConfigBuilder
setCaptions(dynamic captions) → FeaturesConfigBuilder
setCoverConfig(dynamic coverConfig) → FeaturesConfigBuilder
setDraftsConfig(dynamic draftsConfig) → FeaturesConfigBuilder
setEditorConfig(dynamic editorConfig) → FeaturesConfigBuilder
setGifPickerConfig(dynamic gifPickerConfig) → FeaturesConfigBuilder
setProcessPictureExternally(dynamic processPictureExternally) → FeaturesConfigBuilder
setTemplatesConfig(dynamic templatesConfig) → FeaturesConfigBuilder
setVideoDurationConfig(dynamic videoDurationConfig) → FeaturesConfigBuilder
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited